
import logging

from thanatos import database
from thanatos import questions
from thanatos import categories
from thanatos import ccp_image_server

__version__ = '0.1.0'

_log = logging.getLogger('thanatos')
