

# The Geography category and it's sub-categories
geography = {
    'name': 'Geography',
    'description': 'Questions regarding the solar systems and regions of New Eden.',
}

# Seoncdary Cateogries
geography_regions = {
    'name': 'Regions',
    'description': 'Questions specifically about the regions of New Eden.',
}

geography_miscellaneous = {
    'name': 'Miscellaneous',
    'description': 'Miscellaneous questions about the geography of New Eden.',
}

# The Inventory category it is's sub-categories
inventory = {
    'name': 'Inventory',
    'description': 'Questions regarding the ships, modules, and other items.',
}

inventory_slots = {
    'name': 'Slots',
    'description': 'Questions about the number of different slots ships have.',
}

inventory_ship_id = {
    'name': 'Ship ID',
    'description': 'Questions asking to identify what ship is being described.',
}